MODULE trcctl_cfc
   !!======================================================================
   !!                         ***  trcctl.cfc.F90  ***
   !! TOP :                Control of CFC chemical model
   !!======================================================================
   !!----------------------------------------------------------------------
   !! History :   1.0  !  2005-10 (C. Ethe) assign a parameter to name individual tracers
   !!----------------------------------------------------------------------

#if defined key_cfc

   USE oce_trc
   USE trc


   IMPLICIT NONE
   PRIVATE

   PUBLIC trc_ctl_cfc      ! called by ???

   !!----------------------------------------------------------------------
   !! NEMO/TOP 1.0 , LOCEAN-IPSL (2005) 
   !! $Id$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_ctl_cfc
      !!----------------------------------------------------------------------
      !!                     ***  ROUTINE trc_ctl_cfc  ***
      !!
      !! ** Purpose :   control the cpp options, namelist and files 
      !!----------------------------------------------------------------------
      INTEGER :: jn

      IF(lwp) THEN
          WRITE(numout,*) ' CFC Model '
          WRITE(numout,*) ' '
      ENDIF

      ! Check number of tracers
      ! -----------------------   
      IF( jp_cfc > 2) THEN 
          IF(lwp) THEN 
              WRITE (numout,*) ' ===>>>> : w a r n i n g '
              WRITE (numout,*) ' =======   ============= '
              WRITE (numout,*)                             &
              &   ' STOP, change jp_cfc to 1 or 2 in par_CFC module '  
          END IF 
          STOP 'TRC_CTL'
      END IF 

      ! Check tracer names
      ! ------------------
      IF( jp_cfc == 1 ) THEN
         IF ( jp11 == 1 ) THEN
            IF ( ctrcnm(jp11) /= 'CFC11') THEN
               ctrcnm(jp11) = 'CFC11'
               ctrcnl(jp11) = 'Chlorofuorocarbone 11 concentration'
            ENDIF
         ENDIF
         IF( jp12 == 1 ) THEN
            IF ( ctrcnm(jp12) /= 'CFC12') THEN
               ctrcnm(jp12) = 'CFC12'
               ctrcnl(jp12) = 'Chlorofuorocarbone 12 concentration'
            ENDIF
         ENDIF
      ENDIF

      IF( jp_cfc == 2 ) THEN
         IF ( ctrcnm(jp11) /= 'CFC11' .OR. ctrcnm(jp12) /= 'CFC12' ) THEN 
            ctrcnm(jp11) = 'CFC11'
            ctrcnl(jp11) = 'Chlorofuorocarbone 11 concentration'
            ctrcnm(jp12) = 'CFC12'
            ctrcnl(jp12) = 'Chlorofuorocarbone 12 concentration' 
         ENDIF
      ENDIF

      IF(lwp) THEN
         WRITE (numout,*) ' ===>>>> : w a r n i n g '
         WRITE (numout,*) ' =======   ============= '
         WRITE (numout,*) ' we force tracer names'
         DO jn = jp_cfc0, jp_cfc1
            WRITE(numout,*) ' tracer nb: ',jn,' name = ',ctrcnm(jn), ctrcnl(jn)
         END DO
         WRITE(numout,*) ' '
      ENDIF 


      ! Check tracer units
      ! ------------------
      DO jn = jp_cfc0, jp_cfc1
        IF( ctrcun(jn) /= 'mole/m3' ) THEN
            ctrcun(jn) = 'mole/m3'
            IF(lwp) THEN
               WRITE (numout,*) ' ===>>>> : w a r n i n g '
               WRITE (numout,*) ' =======   ============= '
               WRITE (numout,*) ' we force tracer unit'
               WRITE(numout,*) ' tracer  ',ctrcnm(jn), 'UNIT= ',ctrcun(jn)
               WRITE(numout,*) ' '
            ENDIF 
         ENDIF 
      END DO              
      !
   END SUBROUTINE trc_ctl_cfc

#else
   !!----------------------------------------------------------------------
   !!  Empty module :                                                No CFC
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_ctl_cfc                      ! Dummy routine
   END SUBROUTINE trc_ctl_cfc
#endif

   !!======================================================================
END MODULE trcctl_cfc
